@@ -10,7 +10,7 @@ import aiocells
 logger = logging.getLogger()
 
 
-def main():
+async def async_main():
 
     clock = aiocells.ModClock()
     graph = aiocells.DependencyGraph()
@@ -23,10 +23,6 @@ def main():
     printer = aiocells.ModPrinter(clock, time, "time changed to {value}")
     graph.add_precedence(time, printer)
 
-    # Set the time after 0 seconds
-    timer_0 = functools.partial(aiocells.timer, 0, time)
-    graph.add_precedence(timer_0, time)
-
     # Set the time after 1 second
     timer_1 = functools.partial(aiocells.timer, 1, time)
     graph.add_precedence(timer_1, time)
@@ -35,4 +31,9 @@ def main():
     timer_3 = functools.partial(aiocells.timer, 3, time)
     graph.add_precedence(timer_3, time)
 
-    asyncio.run(aiocells.compute_flow(graph))
+    while await aiocells.compute_flow(graph):
+        pass
+
+
+def main():
+    asyncio.run(async_main())
