@@ -17,18 +17,15 @@ def subgraph(name, period):
     )
     graph.add_precedence(time, printer)
 
-    timer_0 = functools.partial(aiocells.timer, 0, time)
-    graph.add_precedence(timer_0, time)
-
-    repeat_timer = aiocells.repeat(functools.partial(
+    timer = functools.partial(
         aiocells.timer, period, time
-    ))
-    graph.add_precedence(repeat_timer, time)
+    )
+    graph.add_precedence(timer, time)
 
     return graph
 
 
-def main():
+async def async_main():
 
     graph = aiocells.DependencyGraph()
 
@@ -42,4 +39,9 @@ def main():
     print("Ctrl-C to exit the demo")
     print()
 
-    asyncio.run(aiocells.compute_flow(graph))
+    while await aiocells.compute_flow(graph):
+        pass
+
+
+def main():
+    asyncio.run(async_main())
