@@ -14,7 +14,7 @@ async def async_printer(variable):
     print(f"value: {variable.value}")
 
 
-def main():
+async def async_main():
 
     # Tests an async internal node in a flow graph
 
@@ -34,7 +34,12 @@ def main():
     print()
     print("Ctrl-C to exit the demo")
     print()
-    repeat_timer = aiocells.repeat(functools.partial(aiocells.timer, 1, time))
+    repeat_timer = functools.partial(aiocells.timer, 1, time)
     graph.add_precedence(repeat_timer, time)
 
-    asyncio.run(aiocells.compute_flow(graph))
+    while await aiocells.compute_flow(graph):
+        pass
+
+
+def main():
+    asyncio.run(async_main())
